**    ModelEco : MODELling in mathematical programming for the ECOnomic analysis of agriculture    **

*-----------------------------------------------------------------------------*
$Ontext
Name             standardDeviation_empty.gms
Sequence         3 - Risk and time in models
Type             LP
GAMS language
Description
" A given farm can grow three types of crop, wheat, maize and tomato, and use two crop practices, extensive and intensive.
The area to be cultivated must be determined for each crop-technology combination, knowing that :
The objective of the farmer is maximize his income.

Water needs are as follows :
               Water needs (thousands of m3)
Technology        extensive        intensive
Wheat                0                2
Maize                4                6
Tomato               3                5
 Labour needs are as follows :
                  Labour needs (h/ha)
                  Technology            Period
                                 Winter        Summer
Wheat             extensive        10             5
                  intensive        15            10
Maize             extensive        10            35
                  intensive        10            40
Tomato            extensive        10            70
                  intensive        10            90

Gross margins vary from year to year. In the last ten years they have been as follows:

             Y1     Y2    Y3    Y4    Y5    Y6    Y7    Y8    Y9   Y10
Wheat.ext   415   540   335   360   300   405   490   265   600   540
Wheat.int   424   744   364   374   324   564   374   284   474   574
Maize.ext   365  1170   770   730   850   790  1180   610   925   610
Maize.int   600  1310   810   990   900   870  1710   630  1350   830
tomato.ext  1940   230  2200   785  1120  2050   785  1600  1305    35
tomato.int  1865   240  3635   705  2005  2285  1005  2735  1645   -20

The selling price of wheat is 150/ton, that of maize 150/ton, and that of tomato 185/ton.
The farm area is 50 ha, the farmer can work 2000 hours a year
and has 150 thousand m3 for irrigation.
The farmer has the possibility of hiring employees at 10 euros per hour,
to buy water at a price of 50 euros per thousand m3
and to rent land at 500/ha."

$offtext

*               RISK-FREE AGRICULTURAL MODEL *
*           Land rental, labour and irrigation *
*          Introduction of extensive technologies*

*~~~~~~~~~~~~~~~~~~~~~~~~ DECLARATION ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*
sets   C Crops           /Wheat,Maize,tomato/
       T Technology    /ext extensive,int intensive/
       S Season  /winter ,summer /
       K states of nature GM  /K01*K10/

*~~~~~~~~~~~~~~~~~~~~~~~~   DATA  ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*
scalar
LAND_a    land availability in hectares      /50/
WATER_A   water availability                 /150/
HPHL      hourly price of hired labour       /10/
LAND_P    land price                         /500/
WATER_P   water price                        /50/

phi                                          /1/
;

parameter
prob(K) probability of occurence of state of nature K;
prob(K)=1/card(K)
*the probability is uniformly distributed
;

parameter
LABOUR_A(S) labour availability in hours
/winter  1000
 summer    1000/
;

table LN(C,T,S) labour needs per crop and technology (hours)
             winter  summer
 Wheat.ext      10     5
 Wheat.int      15    10
 Maize.ext      10    35
 Maize.int      10    40
 tomato.ext     10    70
 tomato.int     10    90
;

table WN(C,T) water needs per crop and technology
          ext    int
 Wheat     0      2
 Maize     4      6
 tomato    3      5
;

table GMK(C,T,K) gross margin per crop technology and state of nature (euros)
             K01   K02   K03   K04   K05   K06   K07   K08   K09   K10
Wheat .ext   415   540   335   360   300   405   490   265   600   540
Wheat .int   424   744   364   374   324   564   374   284   474   574
Maize .ext   365  1170   770   730   850   790  1180   610   925   610
Maize .int   600  1310   810   990   900   870  1710   630  1350   830
tomato.ext  1940   230  2200   785  1120  2050   785  1600  1305    35
tomato.int  1865   240  3635   705  2005  2285  1005  2735  1645   -20

;

parameter
AGM(C,T) average gross margin calculated for each crop technology combination ;
AGM(C,T) = sum(k,GMK(C,T,K))/10 ;

*~~~~~~~~~~~~~~~~~~~~~~~~ MODEL  ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*
variables
F
X(C,T)   areas dedicated to the different crops according to the different technologies
SLF(S)   number of hours of hired labour  (hours)
P_WATER  purchased water (1000 m3)
R_LAND   additional land rental (ha)
RI(K)    random income: income for each state of nature
AI       average income
ST       standard deviation

positive variables
X,P_WATER,R_LAND,SLF;

Equations
Income             objective function
Land               land equation
Water              water equation
Lab(S)             labour availability equation per period
Random_Income(K)   random income
Standard_Deviation
objective
;

model agri /all/;

Solve agri using NLP maximizing F ;




